created property
true if the logged in user has been created in the RevenueCat backend for the first time. Note: This won't be valid in the web target.
Implementation
final bool created;
true if the logged in user has been created in the RevenueCat backend for the first time. Note: This won't be valid in the web target.
final bool created;