performRestore abstract method
Called when the user initiates a restore from the paywall.
Return the result of the restore operation.
Implementation
Future<PurchaseLogicResult> performRestore();
Called when the user initiates a restore from the paywall.
Return the result of the restore operation.
Future<PurchaseLogicResult> performRestore();